make_multiple_tables: Make multiple short tables out of one long table

Description Usage Arguments

View source: R/make_multiple_tables.R

Description

Make multiple short tables out of one long table

Usage

1
make_multiple_tables(df, row_length = 30)

Arguments

df

a very long table

row_length

the amount of rows per each table


shilohfling/IRatUNLV documentation built on Dec. 23, 2021, 1:23 a.m.